summaryrefslogtreecommitdiff
path: root/include/protocol.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/protocol.h')
-rw-r--r--include/protocol.h81
1 files changed, 35 insertions, 46 deletions
diff --git a/include/protocol.h b/include/protocol.h
index aabb5b022..6af0ed21c 100644
--- a/include/protocol.h
+++ b/include/protocol.h
@@ -18,8 +18,7 @@
*/
-#ifndef PROTOCOL_H
-#define PROTOCOL_H
+#pragma once
#include "hashcomp.h"
@@ -27,23 +26,22 @@ class User;
typedef std::vector<std::string> parameterlist;
-class ProtoServer
+class ProtocolInterface
{
public:
- std::string servername;
- std::string parentname;
- std::string gecos;
- unsigned int usercount;
- unsigned int opercount;
- unsigned int latencyms;
-};
+ class ServerInfo
+ {
+ public:
+ std::string servername;
+ std::string parentname;
+ std::string gecos;
+ unsigned int usercount;
+ unsigned int opercount;
+ unsigned int latencyms;
+ };
-typedef std::list<ProtoServer> ProtoServerList;
+ typedef std::vector<ServerInfo> ServerList;
-class ProtocolInterface
-{
- public:
- ProtocolInterface() { }
virtual ~ProtocolInterface() { }
/** Send an ENCAP message to one or more linked servers.
@@ -69,27 +67,13 @@ class ProtocolInterface
virtual void SendTopic(Channel* channel, std::string &topic) { }
/** Send mode changes for an object.
* @param target The channel name or user to send mode changes for.
* @param modedata The mode changes to send.
* @param translate A list of translation types
*/
- virtual void SendMode(const std::string &target, const parameterlist &modedata, const std::vector<TranslateType> &translate) { }
-
- /** Convenience function, string wrapper around the above.
- */
- virtual void SendModeStr(const std::string &target, const std::string &modeline)
- {
- irc::spacesepstream x(modeline);
- parameterlist n;
- std::vector<TranslateType> types;
- std::string v;
- while (x.GetToken(v))
- {
- n.push_back(v);
- types.push_back(TR_TEXT);
- }
- SendMode(target, n, types);
- }
+ virtual void SendMode(User* source, User* usertarget, Channel* chantarget, const parameterlist& modedata, const std::vector<TranslateType>& translate) { }
/** Send a notice to users with a given snomask.
* @param snomask The snomask required for the message to be sent.
@@ -107,34 +91,39 @@ class ProtocolInterface
* @param target The channel to message.
* @param status The status character (e.g. %) required to recieve.
* @param text The message to send.
+ * @param type The message type (MSG_PRIVMSG or MSG_NOTICE)
*/
- virtual void SendChannelPrivmsg(Channel* target, char status, const std::string &text) { }
+ virtual void SendMessage(Channel* target, char status, const std::string& text, MessageType type = MSG_PRIVMSG) { }
- /** Send a notice to a channel.
- * @param target The channel to message.
- * @param status The status character (e.g. %) required to recieve.
+ /** Send a message to a user.
+ * @param target The user to message.
* @param text The message to send.
+ * @param type The message type (MSG_PRIVMSG or MSG_NOTICE)
*/
- virtual void SendChannelNotice(Channel* target, char status, const std::string &text) { }
+ virtual void SendMessage(User* target, const std::string& text, MessageType type = MSG_PRIVMSG) { }
- /** Send a message to a user.
- * @param target The user to message.
+ /** Send a notice to a channel.
+ * @param target The channel to message.
+ * @param status The status character (e.g. %) required to recieve.
* @param text The message to send.
*/
- virtual void SendUserPrivmsg(User* target, const std::string &text) { }
+ void SendChannelNotice(Channel* target, char status, const std::string &text)
+ {
+ SendMessage(target, status, text, MSG_NOTICE);
+ }
/** Send a notice to a user.
* @param target The user to message.
* @param text The message to send.
*/
- virtual void SendUserNotice(User* target, const std::string &text) { }
+ void SendUserNotice(User* target, const std::string &text)
+ {
+ SendMessage(target, text, MSG_NOTICE);
+ }
/** Fill a list of servers and information about them.
* @param sl The list of servers to fill.
* XXX: document me properly, this is shit.
*/
- virtual void GetServerList(ProtoServerList &sl) { }
+ virtual void GetServerList(ServerList& sl) { }
};
-
-#endif
-
@@ -69,27 +67,13 @@ class ProtocolInterface
virtual void SendTopic(Channel* channel, std::string &topic) { }
/** Send mode changes for an object.
- * @param target The channel name or user to send mode changes for.
+ * @param source The source of the mode change
+ * @param usertarget The target user, NULL if the target is a channel
+ * @param chantarget The target channel, NULL if the target is a user
* @param modedata The mode changes to send.
* @param translate A list of translation types